#
# spec file for package vocal
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           vocal
Version:        2.3.0
Release:        lp151.1.2
Summary:        A podcast client for the desktop
License:        GPL-3.0-only
Group:          Productivity/Multimedia/Other
Url:            https://launchpad.net/vocal
Source:         https://github.com/needle-and-thread/vocal/archive/%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  rsvg-view
BuildRequires:  update-desktop-files
BuildRequires:  vala
BuildRequires:  pkgconfig(clutter-gst-3.0)
BuildRequires:  pkgconfig(clutter-gtk-1.0)
BuildRequires:  pkgconfig(gdk-x11-3.0)
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(granite)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(webkit2gtk-4.0)
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%glib2_gsettings_schema_requires

%description
A podcast application designed for Elementary OS and other GTK-based
Linux desktops. Includes a built-in video player, automatic updating,
smart library management, library importing and exporting, custom
skip intervals, and more.

%lang_package

%prep
%setup -q

%build
%cmake
make %{?_smp_mflags}

%install
%cmake_install %{?_smp_mflags}
%find_lang %{name} %{?no_lang_C}

# CONVERT SVG ICONS INSTALLED INTO NON-SCALABLE DIR TO PNG ONES
for i in 16 22 24 32 48 64 128
do
  rsvg-convert  -o %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/com.github.needle-and-thread.vocal.png \
    %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/com.github.needle-and-thread.vocal.svg
  rm %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/com.github.needle-and-thread.vocal.svg
done

%suse_update_desktop_file com.github.needle-and-thread.vocal Player
%fdupes %{buildroot}%{_datadir}/locale/

%if 0%{?suse_version} <= 1320
%post
%glib2_gsettings_schema_post
%icon_theme_cache_post
%desktop_database_post

%postun
%glib2_gsettings_schema_postun
%icon_theme_cache_postun
%desktop_database_postun
%endif

%files
%defattr(-,root,root)
%doc %attr(0644,root,root) AUTHORS COPYING README.md
%{_bindir}/com.github.needle-and-thread.vocal
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/*.appdata.xml
%{_datadir}/applications/com.github.needle-and-thread.vocal.desktop
%{_datadir}/glib-2.0/schemas/*.xml
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/%{name}

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Thu Nov 15 2018 badshah400@gmail.com
- Update to version 2.3.0:
  + Added new in-app volume controls.
  + Dramatic improvements to the new episode count badges.
  + Improved the search view to make it clear when Vocal is
    loading results from iTunes.
  + Podcasts licensed as Creative Commons now display a Creative
    Commons logo.
  + Improved look and feel throughout the app.
  + New episodes are now sorted by release date rather than just
    their position in the RSS feed (most users will not notice a
    difference as this was an edge-case).
  + Fixed navigation issues that could cause new users to get
    stuck during the setup process.
  + Fixed several issues with the new episodes view button either
    being visible when it should not be, or not being visible when
    it should.
  + Database handling and performance improvements.
  + General stability improvements.
* Mon Apr 30 2018 badshah400@gmail.com
- Update to version 2.2.0:
  * Fixed the infamous "freeze on launch" bug which prevented some
    users from accessing their library.
  * Added a New Episode view to see all the unplayed episodes in
    your library at once.
  * Fixed an annoyance where Vocal would sometimes re-download an
    episode that had already been downloaded.
  * Performance and stability improvements with checking for new
    episodes.
  * Improved performance of the iTunes podcast directory
    (specifically related to the loading of hi res images).
  * Improved logging and debugging support.
  * Many other small performance and stability enhancements.
* Mon Feb  5 2018 badshah400@gmail.com
- Update to version 2.1.6:
  * This update fixes an issue where the .desktop file was using
    the RDNN instead of the actual app name.
* Tue Jan  9 2018 badshah400@gmail.com
- Update to version 2.1.5:
  + Bug fixes (undocumented).
* Sun Dec 31 2017 badshah400@gmail.com
- Update to version 2.1.0:
  * Added HiDPI support for all images so everything looks nice
    and sharp no matter how fancy your display is.
  * Fixed an issue where Vocal would not show you the time elapsed
    or remaining in an episode immediately after relaunching the
    app.
  * Reduced the animation time for switching between different
    views so that it feels extra snappy.
  * Gave the search results view a shave and a haircut. Two bits.
  * Fixed a few issues where Vocal would be grouchy about showing
    certain episode descriptions.
  * When importing several podcasts the progress bar now stays one
    size so you can actually judge the progress correctly.
  * You can now drag and drop items in the play queue to rearrange
    their order.
  * Lots more checking to make sure that things exist so it won't
  * crash nearly as much (hopefully never).
- Appdata moved to %%{_datadir}/metainfo/; adapt file list
  accordingly.
- Only run post scripts for openSUSE <= 1320; for newer versions
  rpm triggers take care of running these scripts automatically.
* Sun Jun 25 2017 badshah400@gmail.com
- Update to version 2.0.20:
  * Fixed a major bug that was leading to crashing when clicking
    on certain podcasts in the library view
  * Use the built-in card CSS class for items in the podcast
    directory when running on elementary OS to make things look
    even sexier
  * Added drag-and-drop support to the queue and prevent adding
    duplicate episodes
- Drop vocal-fix-application-icons.patch: incorporated upstream.
* Sat Apr 15 2017 badshah400@gmail.com
- Update vocal-fix-application-icons.patch to fix one additional
  button icon; patch submitted upstream
  (gh#needle-and-thread/vocal#146).
* Thu Apr 13 2017 badshah400@gmail.com
- Update to version 2.0.12-beta.
- Drop vocal-cmake-fix-install-filenames.patch: incorporated
  upstream.
* Mon Feb 13 2017 badshah400@gmail.com
- Update to version 2.0.10-beta.
- Add patch vocal-cmake-fix-install-filenames.patch to fix
  lingering issues relating to the vocalapp -> needle-and-thread
  github project rename.
* Tue Nov 29 2016 badshah400@gmail.com
- Update to version 2.0.8-beta.
- Drop upstreamed patches:
  * vocal-dont-hardcode-paths.patch
  * vocal-crash-on-percent-sign.patch
- Rebase vocal-fix-application-icons.patch.
* Sun Nov 20 2016 badshah400@gmail.com
- Add vocal-crash-on-percent-sign.patch: Fix crashing when
  podcast name contains a "%%" sign.
* Sun Oct 30 2016 badshah400@gmail.com
- Add vocal-fix-application-icons.patch: Fix icons in application
  toolbars not showing up; patch taken from upstream git
  (gh#vocalapp/vocal#31, gh#vocalapp/vocal#82).
* Sun Oct 30 2016 badshah400@gmail.com
- Update to version 2.0.7-beta:
  + Update CMakeLists.txt.
- Drop vocal-fix-webkitgtk-dep.patch, upstreamed.
- Add, rather than replace, new Categories to .desktop file using
  %%suse_update_desktop_file.
* Thu Apr 28 2016 badshah400@gmail.com
- Update to version 2.0.6-beta (use custom version 1.99.x until
  full 2.0 version comes out).
- Add vocal-fix-webkitgtk-dep.patch to fix obvious library
  naming mistake in cmake file
- Add vocal-locale-dir.patch to move all translations from the
  upstream installed custom dir to openSUSE's standard locale dir;
  not only does it make the location of locale files standard, but
  this also allows us to use standard tools like %%find_lang during
  the build process.
- Update build dependencies for new version:
  + pkgconfig(webkit2gtk-4.0)
  + pkgconfig(libsoub-2.4)
  + pkgconfig(gee-0.8)
  + pkgconfig(gthread-2.0)
- Clean up spec file (prepare for sr into Factory):
  + Use full URL for source tarball.
  + Change version number to be consistent with upstream tarball
    naming.
* Sat Mar  5 2016 and.november@opensuse.org
- initial package (version 1.0) for openSUSE
